/**
 * @file
 * Integrates chartist library using Drupal js settings.
 */

(function ($) {
  'use strict';

  Drupal.behaviors.plyr = {
    attach: function (context, settings) {
      var instances = settings['plyr'];

      var plyr_defaults = {
        autoplay: false,
        autoadvance: true,
        loop: false,
        tooltips: {
          controls: true
        },
        captions: {
          defaultActive: true
        }
      };

      for (var player_id in instances) {
        // Skip loop if the property is from prototype.
        if (!instances.hasOwnProperty(player_id)) {
          continue;
        }

        var instance_data = instances[player_id];

        // Merge defaults.
        for (var property in plyr_defaults) {
          if (!instance_data.options.hasOwnProperty(property)) {
            instance_data.options[property] = plyr_defaults[property];
          }
        }

        var selector = '#' + player_id;

        $(context).find(selector).once('plyr_init').each(function (index) {
          var players = plyr.setup(this, instance_data.options);
          if (players.length) {
            var instance = players[0];
            var current_index = 0;
            var initialized = 0;

            // Event handlers.

            // Playlist support.
            $(selector).find('.plyr-playlist a').each(function (index) {
              if (index == 0) {
                $(this).addClass('active');
              }
              $(this).click(function (event) {
                event.preventDefault();
                var item = $(this).attr('data-item');
                if (typeof(instance_data.sources[item]) != 'undefined') {
                  $(selector).find('.plyr-playlist a').removeClass('active');
                  $(this).addClass('active');
                  current_index = item;
                  setSource(instance_data.sources[current_index]);
                }
              });
            });

            // Auto-advance support.
            if (instance_data.options.autoadvance) {
              instance.on('ended', function (event) {
                setTimeout(advance, 250);
              });
            }

            // Methods.

            // Set source method.
            function setSource(source) {
              instance.source(source);
              if (!initialized && !instance_data.options.autoplay) {
                instance.on('ready', function (event) {
                  instance.play();
                });
                initialized = 1;
              }
            }

            function advance() {
              current_index++;
              if (current_index == instance_data.sources.length) {
                if (instance_data.options.loop) {
                  current_index = 0;
                  setSource(instance_data.sources[current_index]);
                }
              }
              else {
                setSource(instance_data.sources[current_index]);
              }
            }
          }
        });

      }
    }
  };
})(jQuery);
