<?php

/**
 * @file
 * Theme preprosess.
 */

/**
 * Preprocess function.
 */
function plyr_preprocess_plyr(&$variables) {

  static $id = 0;

  $sources = array();
  foreach ($variables['sources'] as $delta => $data) {
    $sources[$delta] = _plyr_get_source_data($data);
  }
  $primary = $sources[0];

  if (!empty($primary['sources'][0]['type'])) {
    $id++;
    $container_id = $variables['container_id'] = 'plyr-container-' . $id;
    $settings['plyr'][$container_id] = array(
      'options' => $variables['settings']
    );
    $instance_settings = &$settings['plyr'][$container_id];

    switch ($primary['data_type']) {
      case 'external':
        $variables['content'] = array(
          '#theme' => 'plyr_stream',
          '#type' => $primary['sources'][0]['type'],
          '#video_id' => $primary['sources'][0]['src']
        );
        $variables['type'] = 'external';
        break;

      case 'audio':
        $variables['content'] = array(
          '#theme' => 'plyr_audio',
          '#media_files' => $primary['sources']
        );
        $instance_settings['options']['volume'] = 7;
        $variables['type'] = 'audio';
        break;

      case 'video':
        $variables['content'] = array(
          '#theme' => 'plyr_video',
          '#poster' => !empty($variables['poster']) ? file_create_url($variables['poster']->uri) : FALSE,
          '#media_files' => $primary['sources'],
          '#track_files' => isset($primary['tracks']) ? $primary['tracks'] : array()
        );
        $variables['type'] = 'video';
        break;

    }

    // Some common instance settings.
    $instance_settings['options']['iconUrl'] = '/' . libraries_get_path('plyr') . '/dist/plyr.svg';

    // Prepare sources data and playlist.
    if (count($sources) > 1) {
      $instance_settings['sources'] = $sources;

      $variables['playlist'] = array(
        '#theme' => 'item_list',
        '#items' => array()
      );
      foreach ($sources as $delta => $source) {
        $variables['playlist']['#items'][$delta] = l(
          empty($source['title']) ? t('Item') . ' ' . ($delta + 1) : $source['title'],
          'javascript:void(0);',
          array(
            'fragment' => '',
            'external' => TRUE,
            'attributes' => array(
              'data-item' => $delta
            )
          )
        );
      }
    }

    // Add plyr library and setup code.
    drupal_add_js($settings, 'setting');
    $variables['content']['#attached']['library'][] = array('plyr', 'plyr');
  }
}
